@@ -61,6 +61,52 @@ class Client(object):
     def _delete(self, *args, **kwargs):
         return self._request('delete', *args, **kwargs)
 
+    def _make_order(
+        self,
+        makerMarket,
+        takerMarket,
+        makerAmount,
+        takerAmount,
+        expiration=None,
+    ):
+        '''
+        Make an order object
+
+        :param makerMarket: required
+        :type makerMarket: number
+
+        :param takerMarket: required
+        :type takerMarket: number
+
+        :param makerAmount: required
+        :type makerAmount: number
+
+        :param takerAmount: required
+        :type takerAmount: number
+
+        :param expiration: optional, defaults to 28 days from now
+        :type expiration: number
+
+        :returns: Order
+
+        :raises: DydxAPIError
+        '''
+
+        order = {
+            'makerMarket': makerMarket,
+            'takerMarket': takerMarket,
+            'makerAmount': makerAmount,
+            'takerAmount': takerAmount,
+            'makerAccountOwner': self.public_address,
+            'makerAccountNumber': self.account_number,
+            'takerAccountOwner': self.TAKER_ACCOUNT_OWNER,
+            'takerAccountNumber': self.TAKER_ACCOUNT_NUMBER,
+            'expiration': expiration or utils.epoch_in_four_weeks(),
+            'salt': random.randint(0, 2**256)
+        }
+        order['typedSignature'] = utils.sign_order(order, self.private_key)
+        return order
+
     # -----------------------------------------------------------
     # Public API
     # -----------------------------------------------------------
@@ -342,6 +388,7 @@ class Client(object):
         takerAmount,
         expiration=None,
         fillOrKill=False,
+        postOnly=False,
         clientId=None,
     ):
         '''
@@ -365,6 +412,9 @@ class Client(object):
         :param fillOrKill: optional, defaults to False
         :type fillOrKill: bool
 
+        :param postOnly: optional, defaults to False
+        :type postOnly: bool
+
         :param clientId: optional, defaults to None
         :type clientId: string
 
@@ -373,22 +423,17 @@ class Client(object):
         :raises: DydxAPIError
         '''
 
-        order = {
-            'makerMarket': makerMarket,
-            'takerMarket': takerMarket,
-            'makerAmount': makerAmount,
-            'takerAmount': takerAmount,
-            'makerAccountOwner': self.public_address,
-            'makerAccountNumber': self.account_number,
-            'takerAccountOwner': self.TAKER_ACCOUNT_OWNER,
-            'takerAccountNumber': self.TAKER_ACCOUNT_NUMBER,
-            'expiration': expiration or utils.epoch_in_four_weeks(),
-            'salt': random.randint(0, 2**256)
-        }
-        order['typedSignature'] = utils.sign_order(order, self.private_key)
+        order = self._make_order(
+            makerMarket,
+            takerMarket,
+            makerAmount,
+            takerAmount,
+            expiration,
+        )
 
         return self._post('dex/orders', data=json.dumps(utils.remove_nones({
             'fillOrKill': fillOrKill,
+            'postOnly': postOnly,
             'clientId': clientId,
             'order': {k: str(v) for k, v in order.items()}
         })))
@@ -413,6 +458,75 @@ class Client(object):
             headers={'Authorization': 'Bearer ' + signature}
         )
 
+    def replace_order(
+        self,
+        makerMarket,
+        takerMarket,
+        makerAmount,
+        takerAmount,
+        cancelId,
+        expiration=None,
+        fillOrKill=False,
+        postOnly=False,
+        clientId=None,
+    ):
+        '''
+        Replace an existing order
+
+        :param makerMarket: required
+        :type makerMarket: number
+
+        :param takerMarket: required
+        :type takerMarket: number
+
+        :param makerAmount: required
+        :type makerAmount: number
+
+        :param takerAmount: required
+        :type takerAmount: number
+
+        :param cancelId: required
+        :type cancelId: str
+
+        :param expiration: optional, defaults to 28 days from now
+        :type expiration: number
+
+        :param fillOrKill: optional, defaults to False
+        :type fillOrKill: bool
+
+        :param postOnly: optional, defaults to False
+        :type postOnly: bool
+
+        :param clientId: optional, defaults to None
+        :type clientId: string
+
+        :returns: Order
+
+        :raises: DydxAPIError
+        '''
+
+        order = self._make_order(
+            makerMarket,
+            takerMarket,
+            makerAmount,
+            takerAmount,
+            expiration,
+        )
+
+        cancelSignature = utils.sign_cancel_order(cancelId, self.private_key)
+
+        return self._post(
+            'dex/orders/replace',
+            data=json.dumps(utils.remove_nones({
+                'cancelId': cancelId,
+                'cancelSignature': cancelSignature,
+                'fillOrKill': fillOrKill,
+                'postOnly': postOnly,
+                'clientId': clientId,
+                'order': {k: str(v) for k, v in order.items()},
+            })),
+        )
+
     def get_orderbook(
         self,
         market
