@@ -1,7 +1,6 @@
 import datetime
 import json
 import pytest
-import re
 import requests_mock
 import tests.test_json
 import dydx.util as utils
@@ -34,6 +33,53 @@ PAIRS = ['WETH-DAI', 'DAI-WETH']
 LOCAL_NODE = 'http://0.0.0.0:8545'
 
 
+# ------------ Helper Functions ------------
+
+def _create_additional_matcher(client, cancelId=None):
+
+    def _additional_matcher(request):
+        body = json.loads(request.body)
+        assert not body['fillOrKill']
+        assert not body['postOnly']
+        assert body['order']['takerMarket'] == '0'
+        assert body['order']['makerMarket'] == '1'
+        assert body['order']['takerAmount'] == '1000'
+        assert body['order']['makerAmount'] == '2000'
+        assert body['order']['makerAccountOwner'] == \
+            client.public_address
+        assert body['order']['makerAccountNumber'] == \
+            str(client.account_number)
+        assert body['order']['takerAccountOwner'] == \
+            client.TAKER_ACCOUNT_OWNER
+        assert body['order']['takerAccountNumber'] == \
+            str(client.TAKER_ACCOUNT_NUMBER)
+        assert abs(
+            int(body['order']['expiration']) -
+            utils.epoch_in_four_weeks()) <= 10
+        assert body['order']['salt'].isnumeric()
+        sent_order = body['order']
+        expected_signature = utils.sign_order({
+            'makerMarket': int(sent_order['makerMarket']),
+            'takerMarket': int(sent_order['takerMarket']),
+            'makerAmount': int(sent_order['makerAmount']),
+            'takerAmount': int(sent_order['takerAmount']),
+            'makerAccountOwner': sent_order['makerAccountOwner'],
+            'makerAccountNumber': int(sent_order['makerAccountNumber']),
+            'takerAccountOwner': sent_order['takerAccountOwner'],
+            'takerAccountNumber': int(sent_order['takerAccountNumber']),
+            'expiration': int(sent_order['expiration']),
+            'salt': int(sent_order['salt']),
+        }, client.private_key)
+        assert body['order']['typedSignature'] == expected_signature
+        if cancelId:
+            assert body['cancelId'] == cancelId
+        return True
+
+    return _additional_matcher
+
+
+# ------------ Tests ------------
+
 class TestClient():
 
     # ------------ Constructor ------------
@@ -386,48 +432,12 @@ class TestClient():
     # ------------ create_order ------------
 
     def test_create_order_success(self):
-
-        def additional_matcher(request):
-            body = json.loads(request.body)
-            assert body['fillOrKill'] is False
-            assert body['order']['takerMarket'] == '0'
-            assert body['order']['makerMarket'] == '1'
-            assert body['order']['takerAmount'] == '1000'
-            assert body['order']['makerAmount'] == '2000'
-            assert body['order']['makerAccountOwner'] == \
-                client.public_address
-            assert body['order']['makerAccountNumber'] == \
-                str(client.account_number)
-            assert body['order']['takerAccountOwner'] == \
-                client.TAKER_ACCOUNT_OWNER
-            assert body['order']['takerAccountNumber'] == \
-                str(client.TAKER_ACCOUNT_NUMBER)
-            assert abs(
-                int(body['order']['expiration']) -
-                utils.epoch_in_four_weeks()) <= 10
-            assert body['order']['salt'].isnumeric()
-            sent_order = body['order']
-            expected_signature = utils.sign_order({
-                'makerMarket': int(sent_order['makerMarket']),
-                'takerMarket': int(sent_order['takerMarket']),
-                'makerAmount': int(sent_order['makerAmount']),
-                'takerAmount': int(sent_order['takerAmount']),
-                'makerAccountOwner': sent_order['makerAccountOwner'],
-                'makerAccountNumber': int(sent_order['makerAccountNumber']),
-                'takerAccountOwner': sent_order['takerAccountOwner'],
-                'takerAccountNumber': int(sent_order['takerAccountNumber']),
-                'expiration': int(sent_order['expiration']),
-                'salt': int(sent_order['salt']),
-            }, client.private_key)
-            assert body['order']['typedSignature'] == expected_signature
-            return True
-
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_create_order_json
             rm.post(
                 'https://api.dydx.exchange/v1/dex/orders',
-                additional_matcher=additional_matcher,
+                additional_matcher=_create_additional_matcher(client),
                 json=json_obj
             )
             result = client.create_order(
@@ -465,101 +475,25 @@ class TestClient():
             )
             assert result == json_obj
 
-    # -----------------------------------------------------------
-    # Ethereum Transactions
-    # -----------------------------------------------------------
+    # ------------ replace_order ------------
 
-    def _validate_tx_hash(self, client, tx_hash):
-        assert re.compile("^0x[a-f0-9]{64}").match(tx_hash)
-        receipt = client.get_receipt(tx_hash)
-        assert receipt['transactionHash'].hex() == tx_hash
-
-    # ------------ set_allowance ------------
-
-    def test_set_allowance_eth_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.set_allowance(market=0)
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_set_allowance_dai_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.set_allowance(market=1)
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_set_allowance_unknown_failure(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        with pytest.raises(ValueError) as error:
-            client.set_allowance(market=3)
-        assert 'Invalid market number' in str(error.value)
-
-    # ------------ deposit ------------
-
-    def test_deposit_eth_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.deposit(
-            market=0,
-            wei=1000
-        )
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_deposit_dai_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.deposit(
-            market=1,
-            wei=1000
-        )
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_deposit_unknown_failure(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        with pytest.raises(ValueError) as error:
-            client.deposit(
-                market=3,
-                wei=1000
+    def test_replace_order_success(self):
+        client = Client(PRIVATE_KEY_1)
+        with requests_mock.mock() as rm:
+            json_obj = tests.test_json.mock_create_order_json
+            rm.post(
+                'https://api.dydx.exchange/v1/dex/orders/replace',
+                additional_matcher=_create_additional_matcher(
+                    client,
+                    cancelId=ORDER_HASH
+                ),
+                json=json_obj
             )
-        assert 'Invalid market number' in str(error.value)
-
-    # ------------ withdraw ------------
-
-    def test_withdraw_eth_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.withdraw(
-            market=0,
-            wei=1000
-        )
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_withdraw_dai_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.withdraw(
-            market=1,
-            wei=1000
-        )
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_withdraw_unknown_failure(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        with pytest.raises(ValueError) as error:
-            client.withdraw(
-                market=3,
-                wei=1000
+            result = client.replace_order(
+                makerMarket=1,
+                takerMarket=0,
+                makerAmount=2000,
+                takerAmount=1000,
+                cancelId=ORDER_HASH
             )
-        assert 'Invalid market number' in str(error.value)
-
-    # ------------ withdraw_to_zero ------------
-
-    def test_withdraw_to_zero_eth_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.withdraw_to_zero(market=0)
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_withdraw_to_zero_dai_success(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        tx_hash = client.withdraw_to_zero(market=1)
-        self._validate_tx_hash(client, tx_hash)
-
-    def test_withdraw_to_zero_unknown_failure(self):
-        client = Client(PRIVATE_KEY_1, node=LOCAL_NODE)
-        with pytest.raises(ValueError) as error:
-            client.withdraw_to_zero(market=3)
-        assert 'Invalid market number' in str(error.value)
+            assert result == json_obj
